<?php defined('SYSPATH') or die('No direct script access.');

class Controller_Handler_AdmStudents extends Controller_Handler
{
    const STUDENTS_LIST = '/handler/listStudents';

    public function before() {
        parent::before();

        $this->user->checkAccess(User::RIGHTS_ADMIN);
    }

    public function action_create() {
        $this->user->checkAccess(User::RIGHTS_ADMIN);

        $student = Model_Student::make()
            ->faculty($this->post['facultyID'])
            ->grade($this->post['gradeNum'])
            ->group($this->post['groupNum'])
            ->firstName($this->post['firstName'])
            ->secondName($this->post['secondName'])
            ->lastName($this->post['lastName'])
            ->create();

        $response = ['ID' => $student->ID, 'Code' => $student->ActivationCode];
        $this->response->body(json_encode($response));
    }

    public function action_getGroups() {
        $facultyID = $this->post['facultyID'];
        $gradeID = $this->post['gradeNum'];
        if (($facultyID && $gradeID) != 0) {
            $groups = Model_Faculty::with($facultyID)->getGroups($gradeID);
            $groupsHandled = array();
            $i = $j = $id = 0;
            foreach ($groups as $row) {
                if ($id != $row['SpecID']) {
                    $i++;
                    $j = 0;
                    $id = $row['SpecID'];
                }
                $j++;

                $groupsHandled[$i]['SpecName'] = is_null($row['SpecName']) ? 'Без специализации' : $row['SpecName'];
                $groupsHandled[$i]['SpecAbbr'] = is_null($row['SpecAbbr']) ? '' : $row['SpecAbbr'];

                $groupsHandled[$i]['Groups'][$j]['ID'] = $row['ID'];
                $groupsHandled[$i]['Groups'][$j]['Num'] = $row['GroupNum'];
            }
            $this->response->body(json_encode($groupsHandled));
        }
    }

    public function action_getStudentsList() {
        $faculty = Model_Faculty::with($this->post['facultyID']);

        $twig = Twig::factory(self::STUDENTS_LIST, [
            'List' => $faculty->getStudents($this->post['gradeID'], $this->post['groupID'])
        ]);

        $this->response->body($twig);
    }

    public function action_getStudentsByStudyGroup() {
        $groupID = $this->post['studyGroupID'];

        if ($groupID != 0) {
            # todo: links to dean / admin page
            $twig = Twig::factory(self::STUDENTS_LIST);
            $twig->List = Model_Students::ofGroup($groupID);
            $this->response->body($twig);
        }
    }

    # todo: check, is it used?
    public function action_getStudentsByFaculty() {
        $faculty = Model_Faculty::with($this->post['facultyID']);

        $twig = Twig::factory(self::STUDENTS_LIST, [
            'List' => $faculty->getStudents()
        ]);

        $this->response->body($twig);
    }

    public function action_getStudentsByName() {
        $twig = Twig::factory(self::STUDENTS_LIST);

        $facultyID = (int) $this->post['facultyID'];
        $gradeID = (int) $this->post['gradeID'];
        $groupID = (int) $this->post['groupID'];
        $name = $this->post['name'];

        if (strlen($name) >= 3) {
            $twig->List = Model_Students::searchStudentsByName($name, $facultyID, $gradeID, $groupID);
        }

        $this->response->body($twig);
    }

    public function action_giveLeave() {
        // fixme
        $id = (int) $this->get['id'];
        Model_Student::load($id)->toAcademicLeave();
    }

    public function action_stopLeave() {
        // fixme
        $id = (int) $this->get['id'];
        //Model_Student::load($id)
        //    ->attach()
    }
}
